@@ -2,17 +2,17 @@
 
 #ifndef clipper_z_hpp
 #ifdef clipper_hpp
-#error "You should include the clipper_z.hpp first"
+#error "You should include clipper_z.hpp before clipper.hpp"
 #endif
 
 #define clipper_z_hpp
 
 // Enable the Z coordinate support.
-#define use_xyz
+#define CLIPPERLIB_USE_XYZ
 
 #include "clipper.hpp"
 
 #undef clipper_hpp
-#undef use_xyz
+#undef CLIPPERLIB_USE_XYZ
 
 #endif // clipper_z_hpp
