@@ -1,3 +1,7 @@
+///|/ Copyright (c) Prusa Research 2020 - 2023 Vojtěch Bubník @bubnikv, Pavel Mikuš @Godrak, Tomáš Mészáros @tamasmeszaros, Lukáš Matěna @lukasmatena, Lukáš Hejl @hejllukas
+///|/
+///|/ PrusaSlicer is released under the terms of the AGPLv3 or higher
+///|/
 // AABB tree built upon external data set, referencing the external data by integer indices.
 // The AABB tree balancing and traversal (ray casting, closest triangle of an indexed triangle mesh)
 // were adapted from libigl AABB.{cpp,hpp} Copyright (C) 2015 Alec Jacobson <alecjacobson@gmail.com>
@@ -13,6 +17,7 @@
 
 #include <Eigen/Geometry>
 
+#include "BoundingBox.hpp"
 #include "Utils.hpp" // for next_highest_power_of_2()
 
 // Definition of the ray intersection hit structure.
@@ -83,6 +88,13 @@ public:
 	//        to split around.
 	template<typename SourceNode>
 	void build(std::vector<SourceNode> &&input)
+	{
+		this->build_modify_input(input);
+        input.clear();
+	}
+
+	template<typename SourceNode>
+	void build_modify_input(std::vector<SourceNode> &input)
 	{
         if (input.empty())
 			clear();
@@ -91,7 +103,6 @@ public:
             m_nodes.assign(next_highest_power_of_2(input.size()) * 2 - 1, Node());
             build_recursive(input, 0, 0, input.size() - 1);
 		}
-        input.clear();
 	}
 
 	const std::vector<Node>& 	nodes() const { return m_nodes; }
@@ -211,6 +222,23 @@ using Tree3f = Tree<3, float>;
 using Tree2d = Tree<2, double>;
 using Tree3d = Tree<3, double>;
 
+// Wrap a 2D Slic3r own BoundingBox to be passed to Tree::build() and similar
+// to build an AABBTree over coord_t 2D bounding boxes.
+class BoundingBoxWrapper {
+public:
+	using BoundingBox = Eigen::AlignedBox<coord_t, 2>;
+	BoundingBoxWrapper(const size_t idx, const Slic3r::BoundingBox &bbox) :
+        m_idx(idx),
+        // Inflate the bounding box a bit to account for numerical issues.
+        m_bbox(bbox.min - Point(SCALED_EPSILON, SCALED_EPSILON), bbox.max + Point(SCALED_EPSILON, SCALED_EPSILON)) {}
+    size_t             idx() const { return m_idx; }
+    const BoundingBox& bbox() const { return m_bbox; }
+    Point              centroid() const { return ((m_bbox.min().cast<int64_t>() + m_bbox.max().cast<int64_t>()) / 2).cast<int32_t>(); }
+private:
+    size_t             m_idx;
+    BoundingBox		   m_bbox;
+};
+
 namespace detail {
 	template<typename AVertexType, typename AIndexedFaceType, typename ATreeType, typename AVectorType>
 	struct RayIntersector {
@@ -513,7 +541,7 @@ namespace detail {
 		const VectorType					 origin;
 
 		inline VectorType closest_point_to_origin(size_t primitive_index,
-		        ScalarType& squared_distance){
+		        ScalarType& squared_distance) const {
 		    const auto &triangle = this->faces[primitive_index];
 		    VectorType closest_point = closest_point_to_triangle<VectorType>(origin,
 		            this->vertices[triangle(0)].template cast<ScalarType>(),
@@ -607,6 +635,37 @@ namespace detail {
 		return up_sqr_d;
 	}
 
+    template<typename IndexedPrimitivesDistancerType, typename Scalar>
+    static inline void indexed_primitives_within_distance_squared_recurisve(const IndexedPrimitivesDistancerType &distancer,
+                                                                            size_t                                node_idx,
+                                                                            Scalar                                squared_distance_limit,
+                                                                            std::vector<size_t>                  &found_primitives_indices)
+    {
+        const auto &node = distancer.tree.node(node_idx);
+        assert(node.is_valid());
+        if (node.is_leaf()) {
+            Scalar sqr_dist;
+            distancer.closest_point_to_origin(node.idx, sqr_dist);
+            if (sqr_dist < squared_distance_limit) { found_primitives_indices.push_back(node.idx); }
+        } else {
+            size_t      left_node_idx  = node_idx * 2 + 1;
+            size_t      right_node_idx = left_node_idx + 1;
+            const auto &node_left      = distancer.tree.node(left_node_idx);
+            const auto &node_right     = distancer.tree.node(right_node_idx);
+            assert(node_left.is_valid());
+            assert(node_right.is_valid());
+
+            if (node_left.bbox.squaredExteriorDistance(distancer.origin) < squared_distance_limit) {
+                indexed_primitives_within_distance_squared_recurisve(distancer, left_node_idx, squared_distance_limit,
+                                                                     found_primitives_indices);
+            }
+            if (node_right.bbox.squaredExteriorDistance(distancer.origin) < squared_distance_limit) {
+                indexed_primitives_within_distance_squared_recurisve(distancer, right_node_idx, squared_distance_limit,
+                                                                     found_primitives_indices);
+            }
+        }
+    }
+
 } // namespace detail
 
 // Build a balanced AABB Tree over an indexed triangles set, balancing the tree
@@ -793,6 +852,33 @@ inline bool is_any_triangle_in_radius(
     return hit_point.allFinite();
 }
 
+// Returns all triangles within the given radius limit
+template<typename VertexType, typename IndexedFaceType, typename TreeType, typename VectorType>
+inline std::vector<size_t> all_triangles_in_radius(
+        // Indexed triangle set - 3D vertices.
+        const std::vector<VertexType> 		&vertices,
+        // Indexed triangle set - triangular faces, references to vertices.
+        const std::vector<IndexedFaceType> 	&faces,
+        // AABBTreeIndirect::Tree over vertices & faces, bounding boxes built with the accuracy of vertices.
+        const TreeType 						&tree,
+        // Point to which the distances on the indexed triangle set is searched for.
+        const VectorType					&point,
+        //Square of maximum distance in which triangles are searched for
+        typename VectorType::Scalar max_distance_squared)
+{
+    auto distancer = detail::IndexedTriangleSetDistancer<VertexType, IndexedFaceType, TreeType, VectorType>
+            { vertices, faces, tree, point };
+
+	if(tree.empty())
+	{
+		return {};
+	}
+
+	std::vector<size_t> found_triangles{};
+	detail::indexed_primitives_within_distance_squared_recurisve(distancer, size_t(0), max_distance_squared, found_triangles);
+	return found_triangles;
+}
+
 
 // Traverse the tree and return the index of an entity whose bounding box
 // contains a given point. Returns size_t(-1) when the point is outside.
@@ -837,48 +923,54 @@ struct Intersecting<Eigen::AlignedBox<CoordType, NumD>> {
 
 template<class G> auto intersecting(const G &g) { return Intersecting<G>{g}; }
 
-template<class G> struct Containing {};
+template<class G> struct Within {};
 
 // Intersection predicate specialization for box-box intersections
 template<class CoordType, int NumD>
-struct Containing<Eigen::AlignedBox<CoordType, NumD>> {
+struct Within<Eigen::AlignedBox<CoordType, NumD>> {
     Eigen::AlignedBox<CoordType, NumD> box;
 
-    Containing(const Eigen::AlignedBox<CoordType, NumD> &bb): box{bb} {}
+    Within(const Eigen::AlignedBox<CoordType, NumD> &bb): box{bb} {}
 
     bool operator() (const typename Tree<NumD, CoordType>::Node &node) const
     {
-        return box.contains(node.bbox);
+        return node.is_leaf() ? box.contains(node.bbox) : box.intersects(node.bbox);
     }
 };
 
-template<class G> auto containing(const G &g) { return Containing<G>{g}; }
+template<class G> auto within(const G &g) { return Within<G>{g}; }
 
 namespace detail {
 
+// Returns true in case traversal should continue,
+// returns false if traversal should stop (for example if the first hit was found).
 template<int Dims, typename T, typename Pred, typename Fn>
-void traverse_recurse(const Tree<Dims, T> &tree,
+bool traverse_recurse(const Tree<Dims, T> &tree,
                       size_t               idx,
                       Pred &&              pred,
                       Fn &&                callback)
 {
     assert(tree.node(idx).is_valid());
 
-    if (!pred(tree.node(idx))) return;
+    if (!pred(tree.node(idx))) 
+    	// Continue traversal.
+    	return true;
 
     if (tree.node(idx).is_leaf()) {
-        callback(tree.node(idx).idx);
+    	// Callback returns true to continue traversal, false to stop traversal.
+        return callback(tree.node(idx));
     } else {
 
         // call this with left and right node idx:
-        auto trv = [&](size_t idx) {
-            traverse_recurse(tree, idx, std::forward<Pred>(pred),
-                             std::forward<Fn>(callback));
+        auto trv = [&](size_t idx) -> bool {
+            return traverse_recurse(tree, idx, std::forward<Pred>(pred),
+                                    std::forward<Fn>(callback));
         };
 
         // Left / right child node index.
-        trv(Tree<Dims, T>::left_child_idx(idx));
-        trv(Tree<Dims, T>::right_child_idx(idx));
+        // Returns true if both children allow the traversal to continue.
+        return trv(Tree<Dims, T>::left_child_idx(idx)) &&
+        	   trv(Tree<Dims, T>::right_child_idx(idx));
     }
 }
 
@@ -888,6 +980,7 @@ void traverse_recurse(const Tree<Dims, T> &tree,
 // traverse(tree, intersecting(QueryBox), [](size_t face_idx) {
 //      /* ... */
 // });
+// Callback shall return true to continue traversal, false if it wants to stop traversal, for example if it found the answer.
 template<int Dims, typename T, typename Predicate, typename Fn>
 void traverse(const Tree<Dims, T> &tree, Predicate &&pred, Fn &&callback)
 {
