@@ -27,5 +27,24 @@ public:
 
 } // namespace Slic3r::Arachne
 
+namespace boost::polygon {
+
+template<> struct geometry_concept<Slic3r::Arachne::PolygonsSegmentIndex>
+{
+    typedef segment_concept type;
+};
+
+template<> struct segment_traits<Slic3r::Arachne::PolygonsSegmentIndex>
+{
+    typedef coord_t       coordinate_type;
+    typedef Slic3r::Point point_type;
+
+    static inline point_type get(const Slic3r::Arachne::PolygonsSegmentIndex &CSegment, direction_1d dir)
+    {
+        return dir.to_int() ? CSegment.to() : CSegment.from();
+    }
+};
+
+} // namespace boost::polygon
 
 #endif//UTILS_POLYGONS_SEGMENT_INDEX_H
