@@ -183,15 +183,24 @@ std::vector<SurfaceFill> group_fills(const Layer &layer)
 		        } else if (params.density <= 0)
 		            continue;
 
-		        params.extrusion_role =
-		            is_bridge ?
-		                ExtrusionRole::BridgeInfill :
-		                (surface.is_solid() ?
-		                    (surface.is_top() ? ExtrusionRole::TopSolidInfill : ExtrusionRole::SolidInfill) :
-							ExtrusionRole::InternalInfill);
+		        if (is_bridge) {
+		            params.extrusion_role = ExtrusionRole::BridgeInfill;
+                } else {
+                    if (surface.is_solid()) {
+                        if (surface.is_top()) {
+                            params.extrusion_role = ExtrusionRole::TopSolidInfill;
+                        } else if (surface.surface_type == stSolidOverBridge) {
+                            params.extrusion_role = ExtrusionRole::InfillOverBridge;
+                        } else {
+                            params.extrusion_role = ExtrusionRole::SolidInfill;
+                        }
+                    } else {
+                        params.extrusion_role = ExtrusionRole::InternalInfill;
+                    }
+                }
 		        params.bridge_angle = float(surface.bridge_angle);
 		        params.angle 		= float(Geometry::deg2rad(region_config.fill_angle.value));
-		        
+
 		        // Calculate the actual flow we'll be using for this infill.
 		        params.bridge = is_bridge || Fill::use_bridge_flow(params.pattern);
 				params.flow   = params.bridge ?
@@ -342,7 +351,9 @@ std::vector<SurfaceFill> group_fills(const Layer &layer)
     // Use ipEnsuring pattern for all internal Solids.
     {
         for (size_t surface_fill_id = 0; surface_fill_id < surface_fills.size(); ++surface_fill_id)
-            if (SurfaceFill &fill = surface_fills[surface_fill_id]; fill.surface.surface_type == stInternalSolid) {
+            if (SurfaceFill &fill = surface_fills[surface_fill_id];
+                    fill.surface.surface_type == stInternalSolid
+                    || fill.surface.surface_type == stSolidOverBridge) {
                 fill.params.pattern = ipEnsuring;
             }
     }
