@@ -6,9 +6,14 @@
 #ifndef slic3r_FillLine_hpp_
 #define slic3r_FillLine_hpp_
 
-#include "../libslic3r.h"
+#include <utility>
 
+#include "libslic3r/libslic3r.h"
 #include "FillBase.hpp"
+#include "libslic3r/ExPolygon.hpp"
+#include "libslic3r/Line.hpp"
+#include "libslic3r/Point.hpp"
+#include "libslic3r/Polyline.hpp"
 
 namespace Slic3r {
 
