@@ -4,14 +4,23 @@
 #ifndef LIGHTNING_TREE_NODE_H
 #define LIGHTNING_TREE_NODE_H
 
+#include <stddef.h>
+#include <stdint.h>
 #include <functional>
 #include <memory>
 #include <optional>
 #include <vector>
+#include <utility>
+#include <cinttypes>
+#include <cstddef>
 
-#include "../../EdgeGrid.hpp"
-#include "../../Polygon.hpp"
-#include "SVG.hpp"
+#include "libslic3r/EdgeGrid.hpp"
+#include "libslic3r/Polygon.hpp"
+#include "libslic3r/SVG.hpp"
+#include "libslic3r/BoundingBox.hpp"
+#include "libslic3r/Point.hpp"
+#include "libslic3r/Polyline.hpp"
+#include "libslic3r/libslic3r.h"
 
 //#define LIGHTNING_TREE_NODE_DEBUG_OUTPUT
 
