@@ -89,7 +89,9 @@ private:
     // X,Y,Z,E,F
     float                           m_current_pos[5];
     size_t                          m_current_extruder;
-    GCodeExtrusionRole     m_current_extrusion_role;
+    GCodeExtrusionRole              m_current_extrusion_role;
+    // Set only for external and internal perimeters. The external perimeter has value 0, the first internal perimeter has 1, and so on.
+    std::optional<uint16_t>         m_current_perimeter_index;
     bool                            m_retracted;
     bool                            m_use_relative_e_distances;
 
@@ -164,6 +166,9 @@ private:
         // Extrusion role of this segment.
         GCodeExtrusionRole extrusion_role;
 
+        // Set only for external and internal perimeters. The external perimeter has value 0, the first internal perimeter has 1, and so on.
+        std::optional<uint16_t> perimeter_index;
+
         // Current volumetric extrusion rate.
         float       volumetric_extrusion_rate;
         // Volumetric extrusion rate at the start of this segment.
