@@ -29,7 +29,7 @@ using ThumbnailsList = std::vector<ThumbnailData>;
 
 struct ThumbnailsParams
 {
-	const Vec2ds 	sizes;
+	Vec2ds 	sizes;
 	bool 			printable_only;
 	bool 			parts_only;
 	bool 			show_bed;
