@@ -20,14 +20,16 @@ namespace GCode {
 class WipeTowerIntegration {
 public:
     WipeTowerIntegration(
+        Vec2f pos,
+        double rotation,
         const PrintConfig                                           &print_config,
         const std::vector<WipeTower::ToolChangeResult>              &priming,
         const std::vector<std::vector<WipeTower::ToolChangeResult>> &tool_changes,
         const WipeTower::ToolChangeResult                           &final_purge) :
-        m_left(/*float(print_config.wipe_tower_x.value)*/ 0.f),
-        m_right(float(/*print_config.wipe_tower_x.value +*/ print_config.wipe_tower_width.value)),
-        m_wipe_tower_pos(float(print_config.wipe_tower_x.value), float(print_config.wipe_tower_y.value)),
-        m_wipe_tower_rotation(float(print_config.wipe_tower_rotation_angle)),
+        m_left( 0.f),
+        m_right(float(print_config.wipe_tower_width.value)),
+        m_wipe_tower_pos(pos),
+        m_wipe_tower_rotation(rotation),
         m_extruder_offsets(print_config.extruder_offset.values),
         m_priming(priming),
         m_tool_changes(tool_changes),
