@@ -2,6 +2,9 @@
 ///|/
 ///|/ PrusaSlicer is released under the terms of the AGPLv3 or higher
 ///|/
+#ifndef slic3r_VoronoiVisualUtils_hpp_
+#define slic3r_VoronoiVisualUtils_hpp_
+
 #include <stack>
 
 #include <libslic3r/Geometry.hpp>
@@ -455,3 +458,5 @@ static inline void dump_voronoi_to_svg(
 }
 
 } // namespace Slic3r
+
+#endif // slic3r_VoronoiVisualUtils_hpp_
