@@ -34,11 +34,14 @@ namespace Slic3r {
 
 class Polygon;
 class BoundingBox;
+class ColorPolygon;
 
 using Polygons          = std::vector<Polygon, PointsAllocator<Polygon>>;
 using PolygonPtrs       = std::vector<Polygon*, PointsAllocator<Polygon*>>;
 using ConstPolygonPtrs  = std::vector<const Polygon*, PointsAllocator<const Polygon*>>;
 
+using ColorPolygons     = std::vector<ColorPolygon>;
+
 // Returns true if inside. Returns border_result if on boundary.
 bool contains(const Polygon& polygon, const Point& p, bool border_result = true);
 bool contains(const Polygons& polygons, const Point& p, bool border_result = true);
@@ -328,12 +331,41 @@ template<class I> IntegerOnly<I, Polygons> reserve_polygons(I cap)
     return reserve_vector<Polygon, I, typename Polygons::allocator_type>(cap);
 }
 
-} // Slic3r
+class ColorPolygon : public Polygon
+{
+public:
+    using Color  = uint8_t;
+    using Colors = std::vector<Color>;
+
+    Colors colors;
+
+    ColorPolygon() = default;
+    explicit ColorPolygon(const Points &points, const Colors &colors) : Polygon(points), colors(colors) {}
+    ColorPolygon(std::initializer_list<Point> points, std::initializer_list<Color> colors) : Polygon(points), colors(colors) {}
+    ColorPolygon(const ColorPolygon &other) : ColorPolygon(other.points, other.colors) {}
+    ColorPolygon(ColorPolygon &&other) noexcept : ColorPolygon(std::move(other.points), std::move(other.colors)) {}
+    ColorPolygon(Points &&points, Colors &&colors) : Polygon(std::move(points)), colors(std::move(colors)) {}
+
+    void reverse() override {
+        Polygon::reverse();
+        std::reverse(this->colors.begin(), this->colors.end());
+    }
+
+    ColorPolygon &operator=(const ColorPolygon &other) {
+        this->points = other.points;
+        this->colors = other.colors;
+        return *this;
+    }
+};
+
+using ColorPolygons = std::vector<ColorPolygon>;
+
+} // namespace Slic3r
 
 // start Boost
 #include <boost/polygon/polygon.hpp>
 
-namespace boost { namespace polygon {
+namespace boost::polygon {
     template <>
     struct geometry_concept<Slic3r::Polygon>{ typedef polygon_concept type; };
 
@@ -411,7 +443,7 @@ namespace boost { namespace polygon {
           polygons.assign(input_begin, input_end);
         }
     };
-} }
+} // namespace boost::polygon
 // end Boost
 
 #endif
