@@ -3,10 +3,13 @@
 ///|/ PrusaSlicer is released under the terms of the AGPLv3 or higher
 ///|/
 #include "Clustering.hpp"
-#include "boost/geometry/index/rtree.hpp"
 
 #include <libslic3r/SLA/SpatIndex.hpp>
-#include <libslic3r/BoostAdapter.hpp>
+#include <libslic3r/BoostAdapter.hpp> // IWYU pragma: keep
+#include <boost/geometry.hpp>
+#include <boost/geometry/index/rtree.hpp>
+#include <iterator>
+#include <utility>
 
 namespace Slic3r { namespace sla {
 
