@@ -3,9 +3,12 @@
 ///|/ PrusaSlicer is released under the terms of the AGPLv3 or higher
 ///|/
 #include <libslic3r/SLA/SupportTreeBuilder.hpp>
-#include <libslic3r/SLA/SupportTreeUtils.hpp>
 #include <libslic3r/SLA/SupportTreeMesher.hpp>
 
+#include "libslic3r/BoundingBox.hpp"
+#include "libslic3r/SLA/SupportTree.hpp"
+#include "libslic3r/TriangleMesh.hpp"
+
 namespace Slic3r {
 namespace sla {
 
