@@ -5,8 +5,12 @@
 #ifndef slic3r_OrganicSupport_hpp
 #define slic3r_OrganicSupport_hpp
 
+#include <functional>
+#include <vector>
+
 #include "SupportCommon.hpp"
 #include "TreeSupport.hpp"
+#include "libslic3r/Support/SupportLayer.hpp"
 
 namespace Slic3r
 {
@@ -17,6 +21,8 @@ namespace FFFTreeSupport
 {
 
 class TreeModelVolumes;
+class InterfacePlacer;
+struct TreeSupportSettings;
 
 // Organic specific: Smooth branches and produce one cummulative mesh to be sliced.
 void organic_draw_branches(
