@@ -6,8 +6,14 @@
 #define SRC_LIBSLIC3R_TRIANGLESETSAMPLING_HPP_
 
 #include <admesh/stl.h>
+#include <stddef.h>
+#include <vector>
+#include <cstddef>
+
 #include "libslic3r/Point.hpp"
 
+struct indexed_triangle_set;
+
 namespace Slic3r {
 
 struct TriangleSetSamples {
