@@ -3,11 +3,24 @@
 ///|/ PrusaSlicer is released under the terms of the AGPLv3 or higher
 ///|/
 #include "Triangulation.hpp"
-#include "IntersectionPoints.hpp"
+
 #include <CGAL/Exact_predicates_inexact_constructions_kernel.h>
 #include <CGAL/Constrained_Delaunay_triangulation_2.h>
 #include <CGAL/Triangulation_vertex_base_with_info_2.h>
 #include <CGAL/spatial_sort.h>
+#include <boost/variant/get.hpp>
+#include <limits>
+#include <algorithm>
+#include <cassert>
+#include <cstddef>
+
+#include "IntersectionPoints.hpp"
+#include "libslic3r/ExPolygon.hpp"
+#include "libslic3r/Exception.hpp"
+#include "libslic3r/Line.hpp"
+#include "libslic3r/Point.hpp"
+#include "libslic3r/Polygon.hpp"
+#include "libslic3r/libslic3r.h"
 
 using namespace Slic3r;
 namespace priv{
@@ -73,6 +86,7 @@ inline bool has_self_intersection(
 //#define VISUALIZE_TRIANGULATION
 #ifdef VISUALIZE_TRIANGULATION
 #include "admesh/stl.h" // indexed triangle set
+
 static void visualize(const Points                 &points,
                const Triangulation::Indices &indices,
                const char                   *filename)
