@@ -5,6 +5,8 @@
 #ifndef slic3r_DownloaderFileGet_hpp_
 #define slic3r_DownloaderFileGet_hpp_
 
+#include "Event.hpp"
+
 #include "../Utils/Http.hpp"
 
 #include <memory>
@@ -19,7 +21,7 @@ class FileGet : public std::enable_shared_from_this<FileGet> {
 private:
 	struct priv;
 public:
-	FileGet(int ID, std::string url, const std::string& filename, wxEvtHandler* evt_handler,const boost::filesystem::path& dest_folder);
+	FileGet(int ID, std::string url, const std::string& filename, wxEvtHandler* evt_handler,const boost::filesystem::path& dest_folder, bool load_after);
 	FileGet(FileGet&& other);
 	~FileGet();
 
@@ -27,13 +29,18 @@ public:
 	void cancel();
 	void pause();
 	void resume();
-	static std::string	escape_url(const std::string& url);
-	static bool			is_subdomain(const std::string& url, const std::string& domain);
+	static bool is_subdomain(const std::string& url, const std::string& domain);
 private:
 	std::unique_ptr<priv> p;
 };
+struct DownloadEventData
+{
+    int id;
+    wxString path;
+    bool load_after;
+};
 // int = DOWNLOAD ID; string = file path
-wxDECLARE_EVENT(EVT_DWNLDR_FILE_COMPLETE, wxCommandEvent);
+wxDECLARE_EVENT(EVT_DWNLDR_FILE_COMPLETE, Event<DownloadEventData>);
 // int = DOWNLOAD ID; string = error msg
 wxDECLARE_EVENT(EVT_DWNLDR_FILE_PROGRESS, wxCommandEvent);
 // int = DOWNLOAD ID; string = progress percent
