@@ -22,6 +22,7 @@
 #include "MainFrame.hpp"
 #include "BitmapComboBox.hpp"
 
+#include "Widgets/CheckBox.hpp"
 
 namespace Slic3r {
 namespace GUI {
@@ -165,7 +166,7 @@ ExtruderSequenceDialog::ExtruderSequenceDialog(const DoubleSlider::ExtrudersSequ
     intervals_box_sizer->Add(m_intervals_grid_sizer, 0, wxLEFT, em);
     option_sizer->Add(intervals_box_sizer, 0, wxEXPAND);
 
-    m_random_sequence = new wxCheckBox(this, wxID_ANY, _L("Random sequence"));
+    m_random_sequence = new ::CheckBox(this, _L("Random sequence"));
     m_random_sequence->SetValue(m_sequence.random_sequence);
     m_random_sequence->SetToolTip(_L("If enabled, random sequence of the selected extruders will be used."));
     m_random_sequence->Bind(wxEVT_CHECKBOX, [this](wxCommandEvent& e) {
@@ -173,7 +174,7 @@ ExtruderSequenceDialog::ExtruderSequenceDialog(const DoubleSlider::ExtrudersSequ
         m_color_repetition->Enable(m_sequence.random_sequence);
     });
 
-    m_color_repetition = new wxCheckBox(this, wxID_ANY, _L("Allow next color repetition"));
+    m_color_repetition = new ::CheckBox(this, _L("Allow next color repetition"));
     m_color_repetition->SetValue(m_sequence.color_repetition);
     m_color_repetition->SetToolTip(_L("If enabled, a repetition of the next random color will be allowed."));
     m_color_repetition->Bind(wxEVT_CHECKBOX, [this](wxCommandEvent& e) {m_sequence.color_repetition = e.IsChecked();  });
