@@ -23,7 +23,7 @@
 #include <thread>
 
 #define STB_DXT_IMPLEMENTATION
-#include "stb_dxt/stb_dxt.h"
+#include <stb_dxt.h>
 
 #include <nanosvg/nanosvg.h>
 #include <nanosvg/nanosvgrast.h>
