@@ -96,13 +96,13 @@ public:
 
         if (font_point_size > 0)
             m_normal_font.SetPointSize(font_point_size);
+        else if (parent)
+            m_normal_font.SetPointSize(parent->GetFont().GetPointSize());
 
         /* Because of default window font is a primary display font, 
          * We should set correct font for window before getting em_unit value.
          */
-#ifndef __WXOSX__ // Don't call SetFont under OSX to avoid name cutting in ObjectList 
         this->SetFont(m_normal_font);
-#endif
         this->CenterOnParent();
 #ifdef _WIN32
         update_dark_ui(this);
@@ -111,7 +111,13 @@ public:
         // Linux specific issue : get_dpi_for_window(this) still doesn't responce to the Display's scale in new wxWidgets(3.1.3).
         // So, calculate the m_em_unit value from the font size, as before
 #if !defined(__WXGTK__)
-        m_em_unit = std::max<size_t>(10, 10.0f * m_scale_factor);
+#ifdef _WIN32
+        const double font_to_em_koef = 10./9.;// Default font point size on Windows is 9 pt
+#else // ifdef __WXOSX__
+        const double font_to_em_koef = 10./11.;// Default font point size on OSX is 11 pt
+#endif
+        m_em_unit_from_font_size = int(font_to_em_koef * m_normal_font.GetPointSize());
+        m_em_unit = std::max<int>(10, int(m_scale_factor * m_em_unit_from_font_size));
 #else
         // initialize default width_unit according to the width of the one symbol ("m") of the currently active font of this window.
         m_em_unit = std::max<size_t>(10, this->GetTextExtent("m").x - 1);
@@ -178,7 +184,6 @@ public:
     float   prev_scale_factor() const   { return m_prev_scale_factor; }
 
     int     em_unit() const             { return m_em_unit; }
-//    int     font_size() const           { return m_font_size; }
     const wxFont& normal_font() const   { return m_normal_font; }
     void enable_force_rescale()         { m_force_rescale = true; }
 
@@ -197,7 +202,7 @@ protected:
 private:
     float m_scale_factor;
     int m_em_unit;
-//    int m_font_size;
+    int m_em_unit_from_font_size {10};
 
     wxFont m_normal_font;
     float m_prev_scale_factor;
@@ -206,14 +211,6 @@ private:
 
     int   m_new_font_point_size;
 
-//    void recalc_font()
-//    {
-//        wxClientDC dc(this);
-//        const auto metrics = dc.GetFontMetrics();
-//        m_font_size = metrics.height;
-//         m_em_unit = metrics.averageWidth;
-//    }
-
     // check if new scale is differ from previous
     bool    is_new_scale_factor() const { return fabs(m_scale_factor - m_prev_scale_factor) > 0.001; }
 
@@ -254,7 +251,7 @@ private:
         m_normal_font = this->GetFont();
 
         // update em_unit value for new window font
-        m_em_unit = std::max<int>(10, 10.0f * m_scale_factor);
+        m_em_unit = std::max<int>(10, int(m_scale_factor * m_em_unit_from_font_size));
 
         // rescale missed controls sizes and images
         on_dpi_changed(suggested_rect);
