@@ -977,38 +977,18 @@ static std::string get_connect_state_suffix_for_printer(const Preset& printer_pr
     if (auto printer_state_map = wxGetApp().plater()->get_user_account()->get_printer_state_map();
         !printer_state_map.empty()) {
         
-        for (const auto& [printer_model_nozzle_pair, states] : printer_state_map) {
-            std::string printer_model = printer_preset.config.opt_string("printer_model");
-            const PresetWithVendorProfile& printer_with_vendor = wxGetApp().preset_bundle->printers.get_preset_with_vendor_profile(printer_preset);
-            printer_model = printer_preset.trim_vendor_repo_prefix(printer_model, printer_with_vendor.vendor);
-            
-            if (printer_preset.config.has("nozzle_diameter")) {
-                double nozzle_diameter = static_cast<const ConfigOptionFloats*>(printer_preset.config.option("nozzle_diameter"))->values[0];
-                wxString nozzle_diameter_serialized = double_to_string(nozzle_diameter);
-                nozzle_diameter_serialized.Replace(L",", L".");
-
-                if (printer_model_nozzle_pair.first == printer_model
-                    && printer_model_nozzle_pair.second == GUI::into_u8(nozzle_diameter_serialized)) 
-                {
-                    PrinterStatesCount states_cnt = get_printe_states_count(states);
-
-                    if (states_cnt.available_cnt > 0)
-                        return "_available";
-                    if (states_cnt.busy_cnt > 0)
-                        return "_busy";
-                    return "_offline";
-                }
-            } else {
-                if (printer_model_nozzle_pair.first == printer_model) {
-                    PrinterStatesCount states_cnt = get_printe_states_count(states);
-
-                    if (states_cnt.available_cnt > 0)
-                        return "_available";
-                    if (states_cnt.busy_cnt > 0)
-                        return "_busy";
-                    return "_offline";
-                }
+        const PresetWithVendorProfile& printer_with_vendor = wxGetApp().preset_bundle->printers.get_preset_with_vendor_profile(printer_preset);
+        const std::string trimmed_preset_name = printer_preset.trim_vendor_repo_prefix(printer_preset.name, printer_with_vendor.vendor);
+        for (const auto& [preset_name_from_map, states] : printer_state_map) {
+            if (trimmed_preset_name != preset_name_from_map) {
+                continue;
             }
+            PrinterStatesCount states_cnt = get_printe_states_count(states);
+            if (states_cnt.available_cnt > 0)
+                return "_available";
+            if (states_cnt.busy_cnt > 0)
+                return "_busy";
+            return "_offline";
         }
     }
 
@@ -1029,47 +1009,24 @@ static bool fill_data_to_connect_info_line(  const Preset& printer_preset,
     if (auto printer_state_map = wxGetApp().plater()->get_user_account()->get_printer_state_map();
         !printer_state_map.empty()) {
 
-        for (const auto& [printer_model_nozzle_pair, states] : printer_state_map) {
-            // get printer_model without repo prefix
-            std::string printer_model = printer_preset.config.opt_string("printer_model");
-            const PresetWithVendorProfile& printer_with_vendor = wxGetApp().preset_bundle->printers.get_preset_with_vendor_profile(printer_preset);
-            printer_model = printer_preset.trim_vendor_repo_prefix(printer_model, printer_with_vendor.vendor);
-
-            if (printer_preset.config.has("nozzle_diameter")) {
-                double nozzle_diameter = static_cast<const ConfigOptionFloats*>(printer_preset.config.option("nozzle_diameter"))->values[0];
-                wxString nozzle_diameter_serialized = double_to_string(nozzle_diameter);
-                nozzle_diameter_serialized.Replace(L",", L".");
-
-                if (printer_model_nozzle_pair.first == printer_model
-                    &&  printer_model_nozzle_pair.second == GUI::into_u8(nozzle_diameter_serialized)) 
-                {
-                    PrinterStatesCount states_cnt = get_printe_states_count(states);
-#ifdef _WIN32
-                    connect_available_info->SetLabelMarkup(format_wxstr("%1% %2%", format("<b>%1%</b>", states_cnt.available_cnt), _L("available")));
-                    connect_offline_info  ->SetLabelMarkup(format_wxstr("%1% %2%", format("<b>%1%</b>", states_cnt.offline_cnt),   _L("offline")));
-                    connect_printing_info ->SetLabelMarkup(format_wxstr("%1% %2%", format("<b>%1%</b>", states_cnt.busy_cnt),      _L("printing")));
-#else
-                    connect_available_info->SetLabel(format_wxstr("%1% ", states_cnt.available_cnt));
-                    connect_offline_info  ->SetLabel(format_wxstr("%1% ", states_cnt.offline_cnt));
-                    connect_printing_info ->SetLabel(format_wxstr("%1% ", states_cnt.busy_cnt));
-#endif
-                    return true;
-                }
-            } else {
-                if (printer_model_nozzle_pair.first == printer_model) {
-                    PrinterStatesCount states_cnt = get_printe_states_count(states);
-#ifdef _WIN32
-                    connect_available_info->SetLabelMarkup(format_wxstr("%1% %2%", format("<b>%1%</b>", states_cnt.available_cnt), _L("available")));
-                    connect_offline_info  ->SetLabelMarkup(format_wxstr("%1% %2%", format("<b>%1%</b>", states_cnt.offline_cnt),   _L("offline")));
-                    connect_printing_info ->SetLabelMarkup(format_wxstr("%1% %2%", format("<b>%1%</b>", states_cnt.busy_cnt),      _L("printing")));
-#else
-                    connect_available_info->SetLabel(format_wxstr("%1% ", states_cnt.available_cnt));
-                    connect_offline_info  ->SetLabel(format_wxstr("%1% ", states_cnt.offline_cnt));
-                    connect_printing_info ->SetLabel(format_wxstr("%1% ", states_cnt.busy_cnt));
-#endif
-                    return true;
-                }
+        const PresetWithVendorProfile& printer_with_vendor = wxGetApp().preset_bundle->printers.get_preset_with_vendor_profile(printer_preset);
+        const std::string trimmed_preset_name = printer_preset.trim_vendor_repo_prefix(printer_preset.name, printer_with_vendor.vendor);
+        for (const auto& [preset_name_from_map, states] : printer_state_map) {
+            if (trimmed_preset_name != preset_name_from_map) {
+                continue;
             }
+            
+            PrinterStatesCount states_cnt = get_printe_states_count(states);
+#ifdef _WIN32
+            connect_available_info->SetLabelMarkup(format_wxstr("%1% %2%", format("<b>%1%</b>", states_cnt.available_cnt), _L("available")));
+            connect_offline_info  ->SetLabelMarkup(format_wxstr("%1% %2%", format("<b>%1%</b>", states_cnt.offline_cnt),   _L("offline")));
+            connect_printing_info ->SetLabelMarkup(format_wxstr("%1% %2%", format("<b>%1%</b>", states_cnt.busy_cnt),      _L("printing")));
+#else
+            connect_available_info->SetLabel(format_wxstr("%1% ", states_cnt.available_cnt));
+            connect_offline_info  ->SetLabel(format_wxstr("%1% ", states_cnt.offline_cnt));
+            connect_printing_info ->SetLabel(format_wxstr("%1% ", states_cnt.busy_cnt));
+#endif
+            return true;
         }
     }
     return false;
