@@ -42,6 +42,8 @@ wxDECLARE_EVENT(EVT_REMOVABLE_DRIVE_EJECTED, RemovableDriveEjectEvent);
 using RemovableDrivesChangedEvent = SimpleEvent;
 wxDECLARE_EVENT(EVT_REMOVABLE_DRIVES_CHANGED, RemovableDrivesChangedEvent);
 
+wxDECLARE_EVENT(EVT_REMOVABLE_DRIVE_ADDED, wxCommandEvent);
+
 #if __APPLE__
 	// Callbacks on device plug / unplug work reliably on OSX.
 	#define REMOVABLE_DRIVE_MANAGER_OS_CALLBACKS
@@ -92,12 +94,13 @@ public:
     // Called by Win32 Volume arrived / detached callback.
 	void 		volumes_changed();
 #endif // _WIN32
-
+	// returns copy of m_current_drives (protected by mutex)
+	std::vector<DriveData> get_drive_list();
 private:
 	bool 			 		m_initialized { false };
 	wxEvtHandler*			m_callback_evt_handler { nullptr };
 
-
+	bool					m_first_update{ true };
 #ifndef REMOVABLE_DRIVE_MANAGER_OS_CALLBACKS
 	// Worker thread, worker thread synchronization and callbacks to the UI thread.
 	void 					thread_proc();
