@@ -27,6 +27,7 @@
 #include "Widgets/CheckBox.hpp"
 
 class CheckBox;
+class TextInput;
 
 namespace Slic3r {
 
@@ -91,6 +92,8 @@ class OptionsSearcher
     std::map<std::string, GroupAndCategory> groups_and_categories;
     PrinterTechnology                       printer_technology {ptAny};
     ConfigOptionMode                        mode{ comUndef };
+    TextInput*                              search_input    { nullptr };
+    SearchDialog*                           search_dialog   { nullptr };
 
     std::vector<Option>                     options {};
     std::vector<Option>                     preferences_options {};
@@ -112,8 +115,7 @@ class OptionsSearcher
 
 public:
     OptionViewParameters                    view_params;
-
-    SearchDialog*                           search_dialog { nullptr };
+    wxString                                default_string;
 
     OptionsSearcher();
     ~OptionsSearcher();
@@ -145,9 +147,16 @@ public:
     }
     void sort_options_by_label() { sort_options(); }
 
-    void show_dialog();
+    void update_dialog_position();
+    void edit_search_input();
+    void process_key_down_from_input(wxKeyEvent& e);
+    void check_and_hide_dialog();
+    void set_focus_to_parent();
+    void show_dialog(bool show = true);
     void dlg_sys_color_changed();
     void dlg_msw_rescale();
+
+    void set_search_input(TextInput* input_ctrl);
 };
 
 
@@ -158,11 +167,9 @@ class SearchListModel;
 class SearchDialog : public GUI::DPIDialog
 {
     wxString search_str;
-    wxString default_string;
 
     bool     prevent_list_events {false};
 
-    wxTextCtrl*         search_line         { nullptr };
     wxDataViewCtrl*     search_list         { nullptr };
     SearchListModel*    search_list_model   { nullptr };
     CheckBox*           check_category      { nullptr };
@@ -170,8 +177,6 @@ class SearchDialog : public GUI::DPIDialog
 
     OptionsSearcher*    searcher            { nullptr };
 
-    void OnInputText(wxCommandEvent& event);
-    void OnLeftUpInTextCtrl(wxEvent& event);
     void OnKeyDown(wxKeyEvent& event);
 
     void OnActivate(wxDataViewEvent& event);
@@ -184,7 +189,7 @@ class SearchDialog : public GUI::DPIDialog
     void update_list();
 
 public:
-    SearchDialog(OptionsSearcher* searcher);
+    SearchDialog(OptionsSearcher* searcher, wxWindow* parent);
     ~SearchDialog();
 
     void Popup(wxPoint position = wxDefaultPosition);
@@ -193,6 +198,9 @@ public:
     void msw_rescale();
     void on_sys_color_changed() override;
 
+    void input_text(wxString input);
+    void KeyDown(wxKeyEvent& event) { OnKeyDown(event); }
+
 protected:
     void on_dpi_changed(const wxRect& suggested_rect) override { msw_rescale(); }
 };
