@@ -10,16 +10,16 @@
 #include <memory>
 #include <vector>
 
-#include <wx/event.h>
-
 namespace Slic3r {
 
-
+class VendorProfile;
+typedef std::map<std::string, VendorProfile> VendorMap;
 class AppConfig;
 class PresetBundle;
 class Semver;
+class PresetUpdaterUIStatus;
 
-typedef std::vector<const GUI::ArchiveRepository*> SharedArchiveRepositoryVector;
+typedef std::vector<const ArchiveRepository*> SharedArchiveRepositoryVector;
 
 static constexpr const int SLIC3R_VERSION_BODY_MAX = 256;
 
@@ -33,14 +33,7 @@ public:
 	PresetUpdater &operator=(const PresetUpdater &) = delete;
 	~PresetUpdater();
 
-	// If either version check or config updating is enabled, get the appropriate data in the background and cache it.
-	void sync(const PresetBundle *preset_bundle, wxEvtHandler* evt_handler, SharedArchiveRepositoryVector&& repositories);
-	void cancel_sync();
-
-	void sync_blocking(const PresetBundle* preset_bundle, wxEvtHandler* evt_handler, const SharedArchiveRepositoryVector& repositories);
-
-	// If version check is enabled, check if chaced online slic3r version is newer, notify if so.
-	void slic3r_update_notify();
+	void sync_blocking(const VendorMap& vendors, const SharedArchiveRepositoryVector& repositories, PresetUpdaterUIStatus* ui_status);
 
 	enum UpdateResult {
 		R_NOOP,
@@ -55,35 +48,26 @@ public:
 	enum class UpdateParams {
 		SHOW_TEXT_BOX,				// force modal textbox
 		SHOW_NOTIFICATION,			// only shows notification
-		FORCED_BEFORE_WIZARD		// indicates that check of updated is forced before ConfigWizard opening
+		FORCED_BEFORE_WIZARD,		// indicates that check of updated is forced before ConfigWizard opening
+        SHOW_TEXT_BOX_YES_NO        // like first option but different buttons in dialog
 	};
 
 	// If updating is enabled, check if updates are available in cache, if so, ask about installation.
 	// A false return value implies Slic3r should exit due to incompatibility of configuration.
 	// Providing old slic3r version upgrade profiles on upgrade of an application even in case
 	// that the config index installed from the Internet is equal to the index contained in the installation package.
-	UpdateResult config_update(const Semver &old_slic3r_version, UpdateParams params, const SharedArchiveRepositoryVector& repositories) const;
+	UpdateResult config_update(const Semver &old_slic3r_version, UpdateParams params, const SharedArchiveRepositoryVector& repositories, PresetUpdaterUIStatus* ui_status) const;
 	
 	void update_index_db();
 
 	// "Update" a list of bundles from resources or cache/vendor (behaves like an online update).
-	bool install_bundles_rsrc_or_cache_vendor(std::vector<std::string> bundles, const SharedArchiveRepositoryVector& repositories, bool snapshot = true) const;
+	bool install_bundles_rsrc_or_cache_vendor(std::vector<std::string> bundles, const SharedArchiveRepositoryVector& repositories, PresetUpdaterUIStatus* ui_status, bool snapshot = true) const;
 
-	void on_update_notification_confirm(const SharedArchiveRepositoryVector& repositories);
+	void on_update_notification_confirm(const SharedArchiveRepositoryVector& repositories, PresetUpdaterUIStatus* ui_status);
 
-	bool version_check_enabled() const;
-
-	void add_additional_archive(const std::string& archive_url, const std::string& download_url);
-	void add_additional_archives(const std::vector<std::pair<std::string, std::string>>& archives);
 private:
 	struct priv;
 	std::unique_ptr<priv> p;
-
-	std::vector<std::pair<std::string, std::string>> m_additional_archives;
 };
-
-//wxDECLARE_EVENT(EVT_SLIC3R_VERSION_ONLINE, wxCommandEvent);
-//wxDECLARE_EVENT(EVT_SLIC3R_EXPERIMENTAL_VERSION_ONLINE, wxCommandEvent);
-wxDECLARE_EVENT(EVT_CONFIG_UPDATER_SYNC_DONE, wxCommandEvent);
 }
 #endif
