@@ -1,4 +1,5 @@
-#include <catch2/catch.hpp>
+#include <catch2/catch_test_macros.hpp>
+#include <catch2/benchmark/catch_benchmark_all.hpp>
 #include "test_data.hpp"
 
 #include "libslic3r/GCode/SeamGeometry.hpp"
